@@ -1,7 +1,7 @@
 package Data::Unixish::_pad;
 
-our $DATE = '2016-03-02'; # DATE
-our $VERSION = '1.53'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '1.54'; # VERSION
 
 use 5.010;
 use locale;
@@ -11,7 +11,8 @@ use warnings;
 #use Log::Any '$log';
 
 use String::Pad qw(pad);
-use Text::ANSI::Util qw(ta_pad ta_mbpad);
+use Text::ANSI::Util qw(ta_pad);
+use Text::ANSI::WideUtil qw(ta_mbpad);
 use Text::WideChar::Util qw(mbpad);
 
 sub _pad {
@@ -70,7 +71,7 @@ Data::Unixish::_pad - _pad
 
 =head1 VERSION
 
-This document describes version 1.53 of Data::Unixish::_pad (from Perl distribution Data-Unixish), released on 2016-03-02.
+This document describes version 1.54 of Data::Unixish::_pad (from Perl distribution Data-Unixish), released on 2016-03-11.
 
 =head1 HOMEPAGE
 
