@@ -1,5 +1,8 @@
 package Data::Unixish::trunc;
 
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '1.54'; # VERSION
+
 use 5.010;
 use locale;
 use strict;
@@ -8,11 +11,10 @@ use warnings;
 #use Log::Any '$log';
 
 use Data::Unixish::Util qw(%common_args);
-use Text::ANSI::Util qw(ta_trunc ta_mbtrunc);
+use Text::ANSI::Util qw(ta_trunc);
+use Text::ANSI::WideUtil qw(ta_mbtrunc);
 use Text::WideChar::Util qw(mbtrunc);
 
-our $VERSION = '1.53'; # VERSION
-
 our %SPEC;
 
 $SPEC{trunc} = {
@@ -88,7 +90,7 @@ Data::Unixish::trunc - Truncate string to a certain column width
 
 =head1 VERSION
 
-This document describes version 1.53 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2016-03-02.
+This document describes version 1.54 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
