@@ -1,5 +1,8 @@
 package Data::Unixish::wrap;
 
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '1.54'; # VERSION
+
 use 5.010;
 use strict;
 use syntax 'each_on_array'; # to support perl < 5.12
@@ -7,11 +10,10 @@ use warnings;
 #use Log::Any '$log';
 
 use Data::Unixish::Util qw(%common_args);
-use Text::ANSI::Util qw(ta_wrap ta_mbwrap);
+use Text::ANSI::Util qw(ta_wrap);
+use Text::ANSI::WideUtil qw(ta_mbwrap);
 use Text::WideChar::Util qw(mbwrap);
 
-our $VERSION = '1.53'; # VERSION
-
 our %SPEC;
 
 $SPEC{wrap} = {
@@ -87,7 +89,7 @@ Data::Unixish::wrap - Wrap text
 
 =head1 VERSION
 
-This document describes version 1.53 of Data::Unixish::wrap (from Perl distribution Data-Unixish), released on 2016-03-02.
+This document describes version 1.54 of Data::Unixish::wrap (from Perl distribution Data-Unixish), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
